# Table of Contents

- [aggregation-and-linkage-of-software-records](<./aggregation-and-linkage-of-software-records.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Aggregation and Linkage of Software Records](<./Aggregation-and-Linkage-of-Software-Records.md>)
  - [Overview](<./Aggregation-and-Linkage-of-Software-Records/Overview.md>)
  - [Benefits](<./Aggregation-and-Linkage-of-Software-Records/Benefits.md>)
  - [Synchronization Details](<./Aggregation-and-Linkage-of-Software-Records/Synchronization-Details.md>)
  - [Configuring Aggregation and Linkage](<./Aggregation-and-Linkage-of-Software-Records/Configuring-Aggregation-and-Linkage.md>)
  - [Aggregation Status](<./Aggregation-and-Linkage-of-Software-Records/Aggregation-Status.md>)
  - [Synchronization of Fields with the Reference Catalog](<./Aggregation-and-Linkage-of-Software-Records/Synchronization-of-Fields-with-the-Reference-Catalog.md>)
  - [Viewing Aggregated Items](<./Aggregation-and-Linkage-of-Software-Records/Viewing-Aggregated-Items.md>)
